#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 glirc
version:              2.41
visibility:           public
id:                   glirc-2.41-1JQFuaZnwXM9DZpfjOPdo1
key:                  glirc-2.41-1JQFuaZnwXM9DZpfjOPdo1
license:              ISC
copyright:            2016-2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             Console IRC client
description:
    Console IRC client

    glirc is a console IRC client with an emphasis on providing
    dynamic views into the model of your IRC connections.

    <https://github.com/glguy/irc-core/wiki Documentation Wiki>

category:             Network
abi:                  e8c5619b951effda9d452bf5e6ff3208
exposed:              True
exposed-modules:
    Client.Authentication.Ecdh Client.Authentication.Ecdsa
    Client.Authentication.Scram Client.CApi Client.CApi.Exports
    Client.CApi.Types Client.Commands Client.Commands.Arguments.Parser
    Client.Commands.Arguments.Renderer Client.Commands.Arguments.Spec
    Client.Commands.Certificate Client.Commands.Channel
    Client.Commands.Chat Client.Commands.Connection
    Client.Commands.Docs Client.Commands.Exec Client.Commands.Help
    Client.Commands.Interpolation Client.Commands.Operator
    Client.Commands.Queries Client.Commands.Recognizer
    Client.Commands.TabCompletion Client.Commands.Toggles
    Client.Commands.Types Client.Commands.Window
    Client.Commands.WordCompletion Client.Commands.ZNC
    Client.Configuration Client.Configuration.Colors
    Client.Configuration.Macros Client.Configuration.Notifications
    Client.Configuration.ServerSettings Client.Configuration.Sts
    Client.Docs Client.EventLoop Client.EventLoop.Actions
    Client.EventLoop.Errors Client.EventLoop.Network Client.Hook
    Client.Hook.DroneBLRelay Client.Hook.Matterbridge
    Client.Hook.Snotice Client.Hook.Znc.Buffextras Client.Hooks
    Client.Image Client.Image.Focus Client.Image.Layout
    Client.Image.LineWrap Client.Image.Message
    Client.Image.MircFormatting Client.Image.PackedImage
    Client.Image.Palette Client.Image.StatusLine Client.Image.Textbox
    Client.Log Client.Mask Client.Message Client.Network.Async
    Client.Network.Connect Client.Options Client.State
    Client.State.Channel Client.State.EditBox
    Client.State.EditBox.Content Client.State.Extensions
    Client.State.Focus Client.State.Help Client.State.Network
    Client.State.Target Client.State.Url Client.State.Window
    Client.UserHost Client.View Client.View.Cert
    Client.View.ChannelInfo Client.View.ChannelList
    Client.View.Digraphs Client.View.IgnoreList Client.View.KeyMap
    Client.View.MaskList Client.View.Mentions Client.View.Messages
    Client.View.Palette Client.View.RtsStats Client.View.UrlSelection
    Client.View.UserList Client.View.Who Client.View.WindowSwitch
    Client.View.Windows Client.WhoReply

hidden-modules:
    ContextFilter DigraphQuote Digraphs LensUtils RtsStats StrQuote
    StrictUnit Paths_glirc Build_glirc

import-dirs:          /usr/lib/ghc-9.6.6/site-local/glirc-2.41
library-dirs:         /usr/lib/ghc-9.6.6/site-local/glirc-2.41
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/glirc-2.41
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/glirc
hs-libraries:         HSglirc-2.41-1JQFuaZnwXM9DZpfjOPdo1
include-dirs:         /usr/lib/ghc-9.6.6/site-local/glirc-2.41/include
includes:             include/glirc-api.h
depends:
    HsOpenSSL-0.11.7.9-DT5hmbGM9IAKKAxevMGtcw
    async-2.2.6-AoIAnpP1AE52EgJKBLwe0w
    attoparsec-0.14.4-AJVRZfhVOVzJGMVFtBGw8r base-4.18.2.1
    base64-bytestring-1.2.1.0-AgUw5Mt3ox69IoxxzahjBJ
    bytestring-0.11.5.3 config-schema-1.3.0.0-2ALMnTvbSYLJ5enIZz5VV8
    config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU containers-0.6.7
    curve25519-0.2.8.1-HsxCAeXiqULKnLOPc1BMK7 directory-1.3.8.5
    filepath-1.4.300.1 free-5.2-2OLXliZcvVIEElfmTL5iTo
    githash-0.1.6.3-CH676CG5Ra4A8eItcnmlAT
    hashable-1.4.7.0-GIhdlNoQDSBAO6SjAK3pjT
    hookup-0.8-JVNUnSIsLjBUJkgqr5nGD
    irc-core-2.13-9bCjniGqz4TCvhwZMgVlpW
    kan-extensions-5.2.8-23mgBi0YxA8EonvYZlSq5f
    lens-5.3.4-7EFHuOJ8RipEfJSuyvyaT1
    network-3.1.4.0-FxgQMUnc8In23QMgSfNDtL
    psqueues-0.2.8.3-KNI2YyiDqpkHosEcQN5TJl
    random-1.2.1.3-DsZJWYr04hc2YE8pqhZcvw
    regex-tdfa-1.3.2.5-5LmFHIFwXRgGzMBvrwvbhl
    semigroupoids-6.0.2-BK6IoDXDrpy3Abhcow20lR
    split-0.2.5-47epspW4k5y1JnAPK4u1Hj stm-2.5.1.0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 typed-process-0.2.13.0-5XonszuoAja4pQkGLa2SAh
    unix-2.8.4.0 unordered-containers-0.2.20.1-1VPUCssH1vYLkUFtdr2cZd
    vector-0.13.2.0-DH6UT7zpR061zYDIVIbmaS
    vty-6.2-JlkK46jEoix4dda4PYrHe

haddock-interfaces:   /usr/share/doc/glirc/html/glirc.haddock
haddock-html:         /usr/share/doc/glirc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

